@@ -1,4 +1,10 @@
-class SuccessorGenerator():
+class Successor:
+    def __init__(self, state, msg):
+        self.state = state
+        self.change_msg = msg
+
+
+class SuccessorGenerator:
     """Base class for all successor generators.
     """
     def get_successors(self, state):
@@ -6,6 +12,7 @@ class SuccessorGenerator():
         """
         raise NotImplementedError
 
+
 class ChainingSuccessorGenerator(SuccessorGenerator):
     def __init__(self, nested_generators):
         self.nested_generators = nested_generators
@@ -15,6 +22,7 @@ class ChainingSuccessorGenerator(SuccessorGenerator):
             for s in g.get_successors(state):
                 yield s
 
+
 def make_single_successor_generator(generators):
     if generators is None:
         return ChainingSuccessorGenerator([])
